<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QGeoRouteReplyOsm</name>
    <message>
        <source>Go straight.</source>
        <translation>Geradeaus folgen.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation>Geradeaus auf %1 wechseln.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation>Rechts halten.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation>Rechts halten, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation>Abzweigung rechts nehmen.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation>Abzweigung rechts nehmen, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation>Abzweigung scharf rechts nehmen.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation>Abzweigung scharf rechts nehmen, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation>Wenden Sie, sobald dies möglich ist.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation>Abzweigung scharf links nehmen.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation>Abzweigung scharf links nehmen, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation>Abzweigung links nehmen.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation>Abzweigung links nehmen, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation>Links halten.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation>Links halten, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation>Wegpunkt erreicht.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation>Folgen Sie der Straße.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation>Weiter auf %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation>In den Kreisverkehr einfahren.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation>Nehmen Sie die erste Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation>Nehmen Sie die erste Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation>Nehmen Sie die zweite Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation>Nehmen Sie die zweite Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation>Nehmen Sie die dritte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation>Nehmen Sie die dritte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation>Nehmen Sie die vierte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation>Nehmen Sie die vierte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation>Nehmen Sie die fünfte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation>Nehmen Sie die fünfte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation>Nehmen Sie die sechste Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation>Nehmen Sie die sechste Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation>Nehmen Sie die siebte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation>Nehmen Sie die siebte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation>Nehmen Sie die achte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation>Nehmen Sie die achte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation>Nehmen Sie die neunte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation>Nehmen Sie die neunte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation>Verlassen Sie den Kreisverkehr.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation>Verlassen Sie den Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation>Folgen Sie dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation>Starten Sie am Ende der Straße.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation>Starten Sie am Ende von %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation>Sie haben Ihr Ziel erreicht.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation>Unbekannte Anweisung: %1</translation>
    </message>
</context>
<context>
    <name>QGeoServiceProviderFactoryMapbox</name>
    <message>
        <source>Mapbox plugin requires &apos;mapbox.map_id&apos; and &apos;mapbox.access_token&apos; parameters.
Please visit https://www.mapbox.com</source>
        <translation>Das Mapbox-Plugin erfordert die Parameter &apos;mapbox.map_id&apos; und &apos;mapbox.access_token&apos;.
Bitte besuchen Sie https://www.mapbox.com</translation>
    </message>
</context>
<context>
    <name>QGeoTileFetcherNokia</name>
    <message>
        <source>Mapping manager no longer exists</source>
        <translation>Kartenmanager existiert nicht mehr</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMapDataOsm</name>
    <message>
        <source>Tiles Courtesy of &lt;a href=&apos;http://www.mapquest.com/&apos;&gt;MapQuest&lt;/a&gt;&lt;br/&gt;Data &amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt; contributors</source>
        <translation>Die Kartenabschnitte wurden von &lt;a href=&apos;http://www.mapquest.com/&apos;&gt;MapQuest&lt;/a&gt; zur Verfügung gestellt&lt;br/&gt;Daten &amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt;-Mitwirkende</translation>
    </message>
    <message>
        <source>Maps &amp;copy; &lt;a href=&apos;http://www.thunderforest.com/&apos;&gt;Thunderforest&lt;/a&gt;&lt;br/&gt;Data &amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt; contributors</source>
        <translation>Karten &amp;copy; &lt;a href=&apos;http://www.thunderforest.com/&apos;&gt;Thunderforest&lt;/a&gt;&lt;br/&gt;Daten &amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt;-Mitwirkende</translation>
    </message>
    <message>
        <source>&amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt; contributors</source>
        <translation>&amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt;-Mitwirkende</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineMapbox</name>
    <message>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <source>Mapbox custom map</source>
        <translation>Benutzerdefinierte Karte von Mapbox</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineNokia</name>
    <message>
        <source>Street Map</source>
        <translation>Karte (Normal)</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode</source>
        <translation>Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Karte (Satellite)</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Satellitenkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Karte (Topografie)</translation>
    </message>
    <message>
        <source>Terrain map view in daylight mode</source>
        <translation>Topografische Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Hybrid Map</source>
        <translation>Karte (Hybrid)</translation>
    </message>
    <message>
        <source>Satellite map view with streets in daylight mode</source>
        <translation>Satellitenkarte mit Straßen bei Tageslicht</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Karte (Nahverkehr)</translation>
    </message>
    <message>
        <source>Color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Farbreduzierte Karte mit öffentlichen Nahverkehr bei Tageslicht</translation>
    </message>
    <message>
        <source>Gray Street Map</source>
        <translation>Karte (Grau)</translation>
    </message>
    <message>
        <source>Color-reduced map view in daylight mode</source>
        <translation>Farbreduzierte Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Street Map</source>
        <translation>Karte (Mobil)</translation>
    </message>
    <message>
        <source>Mobile normal map view in daylight mode</source>
        <translation>Mobilkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Terrain Map</source>
        <translation>Karte (Mobil/Topografie)</translation>
    </message>
    <message>
        <source>Mobile terrain map view in daylight mode</source>
        <translation>Mobile topografische Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Hybrid Map</source>
        <translation>Karte (Mobil/Hybrid)</translation>
    </message>
    <message>
        <source>Mobile satellite map view with streets in daylight mode</source>
        <translation>Mobile Satellitenkarte mit Straßen bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Transit Map</source>
        <translation>Karte (Mobil/Nahverkehr)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Farbreduzierte Karte für mobile Nutzung mit öffentlichen Nahverkehr bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Gray Street Map</source>
        <translation>Karte (Mobil/Grau)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in daylight mode</source>
        <translation>Farbreduzierte Karte für mobile Nutzung bei Tageslicht</translation>
    </message>
    <message>
        <source>Custom Street Map</source>
        <translation>Karte (Angepasst)</translation>
    </message>
    <message>
        <source>Night Street Map</source>
        <translation>Karte (Nacht)</translation>
    </message>
    <message>
        <source>Normal map view in night mode</source>
        <translation>Karte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile Night Street Map</source>
        <translation>Karte (Mobil/Nacht)</translation>
    </message>
    <message>
        <source>Mobile normal map view in night mode</source>
        <translation>Mobilkarte bei Nacht</translation>
    </message>
    <message>
        <source>Gray Night Street Map</source>
        <translation>Karte (Nacht/Grau)</translation>
    </message>
    <message>
        <source>Color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Farbreduzierte Karte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile Gray Night Street Map</source>
        <translation>Karte (Mobil/Grau/Nacht)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Farbreduzierte Karte für mobile Nutzung bei Nacht</translation>
    </message>
    <message>
        <source>Pedestrian Street Map</source>
        <translation>Fußgängerkarte</translation>
    </message>
    <message>
        <source>Pedestrian map view in daylight mode</source>
        <translation>Fußgängerkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Street Map</source>
        <translation>Mobile Fußgängerkarte</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in daylight mode for mobile usage</source>
        <translation>Fußgängerkarte für mobilen Einsatz bei Tageslicht</translation>
    </message>
    <message>
        <source>Pedestrian map view in night mode</source>
        <translation>Fußgängerkarte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Night Street Map</source>
        <translation>Mobile Fußgängerkarte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in night mode for mobile usage</source>
        <translation>Fußgängerkarte für mobilen Einsatz bei Nacht</translation>
    </message>
    <message>
        <source>Pedestrian Night Street Map</source>
        <translation>Fußgängerkarte bei Nacht</translation>
    </message>
    <message>
        <source>Car Navigation Map</source>
        <translation>Karte (Fahrzeugnavigation)</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode for car navigation</source>
        <translation>Karte für Fahrzeugnavigation bei Tageslicht</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineOsm</name>
    <message>
        <source>Street Map</source>
        <translation>Straßenkarte</translation>
    </message>
    <message>
        <source>Street map view in daylight mode</source>
        <translation>Ansicht Straßenkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Ansicht Satellitenkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Cycle Map</source>
        <translation>Fahrradkarte</translation>
    </message>
    <message>
        <source>Cycle map view in daylight mode</source>
        <translation>Ansicht Fahrradkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Nahverkehrskarte</translation>
    </message>
    <message>
        <source>Public transit map view in daylight mode</source>
        <translation>Ansicht Nahverkehrskarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Night Transit Map</source>
        <translation>Nahverkehrskarte bei Nacht</translation>
    </message>
    <message>
        <source>Public transit map view in night mode</source>
        <translation>Ansicht Nahverkehrskarte bei Nacht</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Topografische Karte</translation>
    </message>
    <message>
        <source>Terrain map view</source>
        <translation>Ansicht Topografische Karte</translation>
    </message>
    <message>
        <source>Hiking Map</source>
        <translation>Wanderkarte</translation>
    </message>
    <message>
        <source>Hiking map view</source>
        <translation>Ansicht Wanderkarte</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Satellitenkarte</translation>
    </message>
</context>
<context>
    <name>QPlaceManagerEngineOsm</name>
    <message>
        <source>Aeroway</source>
        <translation>Luftverkehr</translation>
    </message>
    <message>
        <source>Amenity</source>
        <translation>Öffentliche Einrichtung</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Highway</source>
        <translation>Straße</translation>
    </message>
    <message>
        <source>Historic</source>
        <translation>Historisch</translation>
    </message>
    <message>
        <source>Land use</source>
        <translation>Landnutzung</translation>
    </message>
    <message>
        <source>Leisure</source>
        <translation>Freizeit</translation>
    </message>
    <message>
        <source>Man made</source>
        <translation>Menschlichen Ursprungs</translation>
    </message>
    <message>
        <source>Natural</source>
        <translation>Natürlich</translation>
    </message>
    <message>
        <source>Place</source>
        <translation>Ort</translation>
    </message>
    <message>
        <source>Railway</source>
        <translation>Eisenbahn</translation>
    </message>
    <message>
        <source>Shop</source>
        <translation>Geschäft</translation>
    </message>
    <message>
        <source>Tourism</source>
        <translation>Tourismus</translation>
    </message>
    <message>
        <source>Waterway</source>
        <translation>Wasserweg</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Netzwerkfehler</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyOsm</name>
    <message>
        <source>Communication error</source>
        <translation>Fehler bei Kommunikation</translation>
    </message>
    <message>
        <source>Response parse error</source>
        <translation>Fehler beim Parsen der Antwort</translation>
    </message>
</context>
<context>
    <name>QtLocationQML</name>
    <message>
        <source>Qt Location requires app_id and token parameters.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation>Qt Location benötigt die app_id und token Parameter.
Bitte registrieren Sie sich unter https://developer.here.com/ um Ihre persönlichen Anmeldedaten zu erhalten.</translation>
    </message>
    <message>
        <source>Saving places is not supported.</source>
        <translation>Speichern von Orten wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Removing places is not supported.</source>
        <translation>Löschen von Orten wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Saving categories is not supported.</source>
        <translation>Speichern von Kategorien wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Removing categories is not supported.</source>
        <translation>Löschen von Kategorien wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Error parsing response.</source>
        <translation>Fehler bim Parsen der Antwort.</translation>
    </message>
    <message>
        <source>Network error.</source>
        <translation>Netzwerkfehler.</translation>
    </message>
    <message>
        <source>Request was canceled.</source>
        <translation>Anfrage wurde abgebrochen.</translation>
    </message>
    <message>
        <source>The response from the service was not in a recognizable format.</source>
        <translation>Die Antwort des Dienstes war in keinem erkennbaren Format.</translation>
    </message>
    <message>
        <source>Plugin property is not set.</source>
        <translation>Plug-in Property wurde nicht gesetzt.</translation>
    </message>
    <message>
        <source>Plugin Error (%1): %2</source>
        <translation>Plug-in Fehler (%1): %2</translation>
    </message>
    <message>
        <source>Plugin Error (%1): Could not instantiate provider</source>
        <translation>Plug-in Fehler: Der %1 - Provider konnte nicht instanziiert werden</translation>
    </message>
    <message>
        <source>Plugin is not valid</source>
        <translation>Plug-in ist ungültig</translation>
    </message>
    <message>
        <source>Unable to initialize categories</source>
        <translation>Kategorien konnten nicht initialisiert werden</translation>
    </message>
    <message>
        <source>Unable to create request</source>
        <translation>Anfrage konnte nicht erstellt werden</translation>
    </message>
</context>
</TS>
